"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.find = void 0;
const path_1 = __importDefault(require("path"));
const util_1 = __importDefault(require("util"));
const glob_1 = __importDefault(require("glob"));
const minimatch_1 = __importDefault(require("minimatch"));
const assertions_1 = require("./assertions");
const cypress_configuration_1 = require("./cypress-configuration");
const MINIMATCH_OPTIONS = { dot: true, matchBase: true };
function find(options = {}) {
    const { integrationFolder, fixturesFolder, supportFile, testFiles, ignoreTestFiles, } = cypress_configuration_1.resolveConfiguration(options);
    const testFilesPatterns = [testFiles].flat();
    const ignoreTestFilesPatterns = [ignoreTestFiles].flat();
    assertions_1.assertIsString(integrationFolder, `Expected "integrationFolder" to be a string, got ${util_1.default.inspect(integrationFolder)}`);
    const globIgnore = [];
    if (supportFile) {
        globIgnore.push(supportFile);
    }
    if (fixturesFolder) {
        assertions_1.assertIsString(fixturesFolder, `Expected "fixturesFolder" to be a string or false, got ${util_1.default.inspect(fixturesFolder)}`);
        globIgnore.push(path_1.default.join(fixturesFolder, "**", "*"));
    }
    const projectPath = cypress_configuration_1.resolveProjectPath(options);
    const globOptions = {
        sort: true,
        absolute: true,
        nodir: true,
        cwd: path_1.default.join(projectPath, integrationFolder),
        ignore: globIgnore.flat(),
    };
    return testFilesPatterns
        .flatMap((testFilesPattern) => glob_1.default.sync(testFilesPattern, globOptions))
        .filter((file) => ignoreTestFilesPatterns.every((ignoreTestFilesPattern) => !minimatch_1.default(file, ignoreTestFilesPattern, MINIMATCH_OPTIONS)));
}
exports.find = find;
