#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findByTags = exports.find = void 0;
const fs_1 = __importDefault(require("fs"));
const util_1 = __importDefault(require("util"));
const gherkin_1 = require("@cucumber/gherkin");
const messages_1 = require("@cucumber/messages");
const tag_expressions_1 = __importDefault(require("@cucumber/tag-expressions"));
const assertions_1 = require("./lib/assertions");
const ast_helpers_1 = require("./lib/ast-helpers");
const cypress_configuration_1 = require("./lib/cypress-configuration");
const cypress_specs_1 = require("./lib/cypress-specs");
Object.defineProperty(exports, "find", { enumerable: true, get: function () { return cypress_specs_1.find; } });
function findByTags(tags) {
    const files = cypress_specs_1.find();
    if (!tags) {
        return files;
    }
    assertions_1.assertIsString(tags, `Expected "integrationFolder" to be a string, got ${util_1.default.inspect(tags)}`);
    const testFilter = tag_expressions_1.default(tags);
    return files
        .filter((file) => file.endsWith(".feature"))
        .filter((file) => {
        const content = fs_1.default.readFileSync(file).toString();
        const newId = messages_1.IdGenerator.incrementing();
        const gherkinDocument = new gherkin_1.Parser(new gherkin_1.AstBuilder(newId)).parse(content);
        const pickles = gherkin_1.compile(gherkinDocument, file, newId);
        return pickles.some((pickle) => { var _a; return testFilter.evaluate(((_a = pickle.tags) === null || _a === void 0 ? void 0 : _a.map(ast_helpers_1.mapTagName)) || []); });
    });
}
exports.findByTags = findByTags;
if (require.main === module) {
    const hasSpecArg = process.argv.some((arg) => arg.match(/^(?:-s|--spec(?:=|$))/));
    if (hasSpecArg) {
        console.error("-s / --spec is already defined");
        process.exit(1);
    }
    const { TAGS } = cypress_configuration_1.resolveEnvironment({});
    console.log(findByTags(TAGS).join(","));
}
